define(
//begin v1.x content
({
	singleSort: "Tekli Sıralama",
	nestedSort: "İç İçe Sıralama",
	ascending: "Artan Düzende",
	descending: "Azalan Düzende",
	sortingState: "${0} - ${1}",
	unsorted: "Bu sütunu sıralama",
	indirectSelectionRadio: "Satır ${0}, tek seçimli, radyo düğmesi",
	indirectSelectionCheckBox: "Satır ${0}, çok seçimli, radyo düğmesi",
	selectAll: "Tümünü seç"
})
//end v1.x content
);

